@@ -12,6 +12,7 @@ import hashlib
 import html
 import json
 import logging
+import math
 import os
 import random
 import re
@@ -1138,6 +1139,23 @@ class URL:
 x_url = URL()
 
 
+# *********************************************** 列表相关模块 --start ***********************************************
+class CustomList:
+    def bucket_cut(self, array: List, length: int) -> List:
+        '''
+        应用场景，把一个列表平均分为多少，也就是分桶策略，把每个桶装多少元素
+        :param array: 需要分桶的原始，列表
+        :param length: 每个桶元素的个数
+        :return:
+        '''
+        return [array[i * length:(i + 1) * length] for i in range(math.ceil(len(array) / length))]
+
+
+x_list = CustomList()
+
+
+# ************************************************ 列表相关模块 --end ************************************************
+
 # ************************************************ URL相关模块 --end ************************************************
 
 
@@ -1249,23 +1267,22 @@ class Text:
         @result:
         """
 
-        contents = text.split("\n")
-        json = {}
-        for content in contents:
-            if content == "\n":
+        if text is None:
+            return None
+
+        headers = text.splitlines()
+        headers_tuples = [header.split(":", 1) for header in headers]
+
+        result_dict = {}
+        for header_item in headers_tuples:
+            if not len(header_item) == 2:
                 continue
 
-            content = content.strip()
-            regex = ["(:?.*?):(.*)", "(.*?):? +(.*)", "([^:]*)"]
+            item_key = header_item[0].strip()
+            item_value = header_item[1].strip()
+            result_dict[item_key] = item_value
 
-            result = self.get_info(content, regex)
-            result = result[0] if isinstance(result[0], tuple) else result
-            try:
-                json[result[0]] = eval(result[1].strip())
-            except:
-                json[result[0]] = result[1].strip()
-
-        return json
+        return result_dict
 
     def cut_string(self, text, length):
         """
